@@ -59,7 +59,7 @@ SEXP C_CMIM(SEXP X,SEXP Y,SEXP K,SEXP Threads){
    }
   }
   #pragma omp critical
-  if(tbs>bs){
+  if((tbs>bs) || (tbs==bs && tbi<bi)){
    bs=tbs;
    bi=tbi;
   }
